@@ -9,16 +9,6 @@ use Carp 'croak';
 use Rstats::Func;
 use Rstats::VectorFunc;
 
-sub is_perl_number {
-  my ($value) = @_;
-  
-  return unless defined $value;
-  
-  return B::svref_2object(\$value)->FLAGS & (B::SVp_IOK | B::SVp_NOK) 
-        && 0 + $value eq $value
-        && $value * 0 == 0
-}
-
 my $type_level = {
   character => 6,
   complex => 5,
@@ -81,7 +71,7 @@ sub parse_index {
       
       if (!@{$index->values}) {
         my $index_values_new = [1 .. $x1_dim->[$i]];
-        $index = Rstats::Func::array($index_values_new);
+        $index = Rstats::Func::new_integer(@$index_values_new);
       }
       elsif ($index->is_character) {
         if ($x1->is_vector) {
@@ -99,7 +89,7 @@ sub parse_index {
             croak "Can't find name" unless defined $value;
             push @$index_new_values, $value;
           }
-          $indexs[$i] = Rstats::Func::array($index_new_values);
+          $indexs[$i] = Rstats::Func::new_integer(@$index_new_values);
         }
         elsif ($x1->is_matrix) {
           
@@ -113,7 +103,7 @@ sub parse_index {
         for (my $i = 0; $i < @{$index->values}; $i++) {
           push @$index_values_new, $i + 1 if $index_values->[$i];
         }
-        $index = Rstats::Func::array($index_values_new);
+        $index = Rstats::Func::new_integer(@$index_values_new);
       }
       elsif ($index->{_minus}) {
         my $index_value_new = [];
@@ -121,7 +111,7 @@ sub parse_index {
         for my $k (1 .. $x1_dim->[$i]) {
           push @$index_value_new, $k unless grep { $_ == -$k } @{$index->values};
         }
-        $index = Rstats::Func::array($index_value_new);
+        $index = Rstats::Func::new_integer(@$index_value_new);
       }
 
       push @indexs, $index;
